@@ -25,7 +25,8 @@ import {
     io,
     iot,
     mqtt,
-    mqtt5
+    mqtt5,
+    CrtError
 } from 'aws-crt';
 
 export {
@@ -38,5 +39,6 @@ export {
     iotjobs,
     iotshadow,
     mqtt,
-    mqtt5
+    mqtt5,
+    CrtError
 }
